package com.sooka.sponest.monitor.camera.service;

import com.sooka.sponest.monitor.camera.domain.CentermonitorTCamerachannel;

import java.util.List;

/**
 * 摄像头通道Service接口
 *
 * @author ruoyi
 * @date 2022-06-10
 */
public interface ICentermonitorTCamerachannelService
{
    /**
     * 查询摄像头通道
     *
     * @param id 摄像头通道主键
     * @return 摄像头通道
     */
    public CentermonitorTCamerachannel selectCentermonitorTCamerachannelById(String id);

    /**
     * 效验通道编码是否唯一
     *
     * @return 摄像头通道
     */
    public String checkChannelUnique(CentermonitorTCamerachannel centermonitorTCamerachannel);

    /**
     * 查询摄像头通道列表
     *
     * @param centermonitorTCamerachannel 摄像头通道
     * @return 摄像头通道集合
     */
    public List<CentermonitorTCamerachannel> selectCentermonitorTCamerachannelList(CentermonitorTCamerachannel centermonitorTCamerachannel);

    /**
     * 新增摄像头通道
     *
     * @param centermonitorTCamerachannel 摄像头通道
     * @return 结果
     */
    public int insertCentermonitorTCamerachannel(CentermonitorTCamerachannel centermonitorTCamerachannel);

    /**
     * 修改摄像头通道
     *
     * @param centermonitorTCamerachannel 摄像头通道
     * @return 结果
     */
    public int updateCentermonitorTCamerachannel(CentermonitorTCamerachannel centermonitorTCamerachannel);

    /**
     * 批量删除摄像头通道
     *
     * @param ids 需要删除的摄像头通道主键集合
     * @return 结果
     */
    public int deleteCentermonitorTCamerachannelByIds(String[] ids);

    /**
     * 删除摄像头通道信息
     *
     * @param id 摄像头通道主键
     * @return 结果
     */
    public int deleteCentermonitorTCamerachannelById(String id);
}
