package com.sooka.sponest.monitor.camera.mapper;

import com.sooka.sponest.monitor.camera.domain.CentermonitorTCamerachannel;
import com.sooka.sponest.monitor.haikang.domain.HaiKangCameraBO;

import java.util.List;

/**
 * 摄像头通道Mapper接口
 *
 * @author ruoyi
 * @date 2022-06-10
 */
public interface CentermonitorTCamerachannelMapper {
    /**
     * 查询摄像头通道
     *
     * @param id 摄像头通道主键
     * @return 摄像头通道
     */
     CentermonitorTCamerachannel selectCentermonitorTCamerachannelById(String id);

    /**
     * 校验摄像头IP唯一
     *
     * @param channelCode 摄像头
     * @return 结果
     */
     CentermonitorTCamerachannel checkChannelUnique(String channelCode);

    /**
     * 查询摄像头通道列表
     *
     * @param centermonitorTCamerachannel 摄像头通道
     * @return 摄像头通道集合
     */
     List<CentermonitorTCamerachannel> selectCentermonitorTCamerachannelList(CentermonitorTCamerachannel centermonitorTCamerachannel);

    /**
     * 获取海康视频服务
     * */
     HaiKangCameraBO getHaiKangVideoServer(String cameraCode);

    /**
     * 新增摄像头通道
     *
     * @param centermonitorTCamerachannel 摄像头通道
     * @return 结果
     */
     int insertCentermonitorTCamerachannel(CentermonitorTCamerachannel centermonitorTCamerachannel);

    /**
     * 修改摄像头通道
     *
     * @param centermonitorTCamerachannel 摄像头通道
     * @return 结果
     */
     int updateCentermonitorTCamerachannel(CentermonitorTCamerachannel centermonitorTCamerachannel);

    /**
     * 删除摄像头通道
     *
     * @param id 摄像头通道主键
     * @return 结果
     */
     int deleteCentermonitorTCamerachannelById(String id);

    /**
     * 批量删除摄像头通道
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteCentermonitorTCamerachannelByIds(String[] ids);

     int deleteCentermonitorTCamerachannelByCameraIds(String[] ids);
}
